@@ -93,5 +93,15 @@ public class Gate extends Supervisor {
 		// 同時接続数がそれを超過するとステータス503を返します。
 		return 0;
 	}
+
+	/**
+	 * PRGパターン遷移の使用。
+	 * @return true:PRGパターンを使用、false:通常のPOST遷移。
+	 */
+	public boolean isPRG() {
+		// SSLアクセラレータ使用時など、元のURLが取得不可能な状況となる場合は
+		// false を返して下さい。
+		return true;
+	}
 }
 
