@@ -5,7 +5,6 @@ package #1.#x;
  * ページファクトリー。
  */
 public class PageLoader extends paraselene.supervisor.PageFactory {
-	private static final long serialVersionUID = 2L;
 	private static PageLoader pf = null;
 
 	/**
@@ -43,5 +42,12 @@ public class PageLoader extends paraselene.supervisor.PageFactory {
 	public static paraselene.supervisor.PageFactory getPageFactory() {
 		return pf;
 	}
+
+	/**
+	 * 初期化失敗設定。
+	 */
+	void failInit() {
+		teapot_f = true;
+	}
 }
 
