@@ -75,6 +75,10 @@ public class Closure extends Forward implements AjaxForward {
 		close_page = page.getParentPage();
 	}
 
+	boolean is_refresh() {
+		return close_page.getPopupType() == null;
+	}
+
 	static boolean isClosure( Page from, Page next, RequestParameter req ) {
 		if ( from == null || next == null )	return false;
 		if ( from.getPopupType() != null )	return true;
