@@ -37,7 +37,7 @@ public class Feedback extends Forward implements AjaxForward {
 	}
 
 	Page getPage( Page from ) {
-		Option.trace( "Feedback#getPage -> %s", from.getUniqueKey() );
+		Option.trace( "Feedback#getPage -> %s", target.getUniqueKey() );
 		return target;
 	}
 
@@ -68,5 +68,10 @@ public class Feedback extends Forward implements AjaxForward {
 		Option.trace( "new OutputCall <- %s", this );
 		return new OutputCall( nk, lp, this, r, sd );
 	}
+
+	CometCall makeCometCall( History h ) {
+		Option.trace( "new CometCall <- %s", this );
+		return new CometCall( h, this );
+	}
 }
 
