@@ -45,5 +45,10 @@ public class JavaScript extends Feedback {
 		Option.trace( "new ScriptOutput <- %s", this );
 		return new ScriptOutput( nk, lp, this, r, sd );
 	}
+
+	CometCall makeCometCall( History h ) {
+		Option.trace( "new ScriptCometCall <- %s", this );
+		return new ScriptCometCall( h, this );
+	}
 }
 
