@@ -142,7 +142,7 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 		synchronized( pending ) {
 			pending.put( out_ret[0].getID(), rd );
 		}
-		rd.redirect_path = new URI( rd.uri );
+		rd.redirect_path = new URI( path );
 		return new Forward( rd.redirect_path, false );
 	}
 
