@@ -300,6 +300,9 @@ public abstract class Supervisor extends HttpServlet {
 
 	private static boolean isMyHost( DataHolder holder, String uri ) {
 		if ( uri == null )	return false;
+		uri = uri.trim();
+		if ( uri.isEmpty() )	return false;
+		if ( uri.charAt( 0 ) == '#' )	return false;
 		try {
 			URI	test = new URI( URIValue.encode( uri, "utf-8" ) );
 			if ( test.isAbsolute() == false ) {
@@ -488,6 +491,7 @@ public abstract class Supervisor extends HttpServlet {
 				}
 				else	ajax = null;
 			}
+			Page[]	history_pages = new Page[0];
 			if ( ajax == null && last_page != null ) {
 				if ( last_page instanceof Null ) {
 					System.out.println( "last page is null" );
@@ -500,6 +504,7 @@ public abstract class Supervisor extends HttpServlet {
 					Page	sub = null;
 					History	history = data.hist.get( (path_data.from_histry != null)? path_data.from_histry: HistorySet.ROOT );
 					if ( history != null ) {
+						history_pages = history.getAllPage( last_page.getID() );
 						sub = history.getPage( last_page.getID() );
 					}
 					if ( sub != null ) {
@@ -560,7 +565,14 @@ public abstract class Supervisor extends HttpServlet {
 				if ( path_data.to_histry != null ){
 					to_key = path_data.to_histry;
 				}
-				Page	do_page = last_page.reflect( req );
+				Page	do_page = null;
+				for ( int i = 0; i < history_pages.length; i++ ) {
+					do_page = history_pages[i].reflect( req );
+					if ( do_page != null )	break;
+				}
+				if ( do_page == null ) {
+					do_page = last_page.reflect( req );
+				}
 				if ( do_page == null && !(last_page instanceof NullPage) && req.getItemCount() > 0 ) {
 					Option.trace( "reflect -> IllegalRequest.DISAPPROVAL_REQUEST" );
 					fw = onIllegalRequest( IllegalRequest.DISAPPROVAL_REQUEST, req, last_page, next_page );
@@ -697,6 +709,7 @@ public abstract class Supervisor extends HttpServlet {
 			if ( holder.data != null )	holder.data.planed_clear = false;
 		}
 		HttpSession	session = holder.getRequest().getSession( true );
+		holder.getHistorySet().replaceSession( session.getId() );
 		session.setAttribute( SESSION_DATA, holder.data );
 		return session;
 	}
